<?php

namespace Drupal\cookie_condition\Plugin\Condition;

use Drupal\Core\Condition\ConditionPluginBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Pass checks if cookie is present & it's value equal to defined value.
 *
 * @Condition(
 *   id = "cookie",
 *   label = @Translation("Cookie"),
 *   description = @Translation("Allows to select cookie & it's value.")
 * )
 */
class Cookie extends ConditionPluginBase {

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form['cookie_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Cookie Name'),
      '#default_value' => $this->configuration['cookie_name'],
    ];

    $form['cookie_value'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Cookie Value'),
      '#default_value' => $this->configuration['cookie_value'],
    ];

    $form = parent::buildConfigurationForm($form, $form_state);

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $this->configuration['cookie_name'] = $form_state->getValue('cookie_name');
    $this->configuration['cookie_value'] = $form_state->getValue('cookie_value');

    parent::submitConfigurationForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'cookie_name' => '',
      'cookie_value' => '',
    ] + parent::defaultConfiguration();
  }

  /**
   * Evaluates the condition and returns TRUE or FALSE accordingly.
   *
   * @return bool
   *   TRUE if the condition has been met, FALSE otherwise.
   */
  public function evaluate() {
    if (empty($this->configuration['cookie_name']) && !$this->isNegated()) {
      return TRUE;
    }

    $cookie_name = $this->configuration['cookie_name'];
    if (isset($_COOKIE[$cookie_name]) && $_COOKIE[$cookie_name] === $this->configuration['cookie_value']) {
      return TRUE;
    }

    return FALSE;
  }

  /**
   * Provides a human readable summary of the condition's configuration.
   */
  public function summary() {
    return t('Cookie "@name" is @negate"@value"', [
      '@name' => $this->configuration['cookie_name'],
      '@value' => $this->configuration['cookie_value'],
      '@negate' => $this->isNegated() ? 'NOT ' : '',
    ]);
  }

}
